==> Mojo-Webqq-2.0.2.tar.gz: Mojo-Webqq-2.0.2/Plugin.md <==
###插件列表

|名称                | 优先级  |当前状态    |github作者    | 功能说明                 
|:-------------------|:--------|:-----------|:-------------|:----------------------------
|[ShowMsg]           |100      |已发布      |sjdy521       |打印客户端接收和发送的消息
|[GroupManage]       |100      |已发布      |sjdy521       |群管理，入群欢迎、限制发图频率等
|[IRCShell]          |99       |已发布      |sjdy521       |Linux环境下通过irc客户端使用qq
|[Openqq]            |98       |已发布      |sjdy521       |提供qq发送消息api接口
|[Perlcode]          |97       |已发布      |sjdy521       |通过qq消息执行perl代码
|[Perldoc]           |96       |已发布      |sjdy521       |通过qq消息查询perl文档
|[StockInfo]         |95       |已发布      |shalk         |查询股票信息
|[ProgramCode]       |94       |已发布      |limengyu1990  |通过qq消息执行代码，支持26种语言
|[Translation]       |93       |已发布      |sjdy521       |多国语言翻译功能
|[MobileInfo]        |93       |已发布      |limengyu1990  |手机号码归属地查询
|[Riddle]            |92       |已发布      |limengyu1990  |输入"猜谜"关键字进行猜谜游戏
|[GasPrice]          |91       |已发布      |hyvinlam      |输入"油价"关键字查询油价
|[KnowledgeBase]     |3        |已发布      |sjdy521       |自定义可编辑问答知识库
|[FuckDaShen]        |1        |已发布      |sjdy521       |对消息中的"大神"关键词进行鄙视
|[Qiandao]           |1        |已发布      |sjdy521       |QQ群每日签到
|[Pu]                |1        |已发布      |bollwarm      |周易、占卜、算命、八卦等关键字触发占卜
|[ZiYue]             |1        |已发布      |bollwarm      |子曰、论语、之乎者也等关键字触发论语语句
|[PostImgVerifycode] |0        |已发布      |sjdy521       |登录验证码发送到邮箱实现远程登录
|[PostQRcode]        |0        |已发布      |sjdy521       |登录二维码发送到邮箱实现远程扫码
|[UploadQRcode]      |0        |已发布      |sjdy521       |二维码上传图床获得公网访问url
|[ShowQRcode]        |0        |已发布      |autodataming  |调用系统图片查看程序来示二维码（目前仅支持win）
|[SmartReply]        |0        |已发布      |sjdy521       |智能聊天回复
|[IPWhere]           |1        |已发布      |bollwarm      |IP库查询
|[LCMD]              |1        |已发布      |bollwarm      |linux命令使用方法查询
|[PW]                |1        |已发布      |bollwarm      |在线分词pullword插件,pullword,分词 关键词触发
|[PostQRcodeToTelegram]|0      |已发布      |HubertZhang   |二维码通过Telegram Bot发至指定账户或频道或群组

[ShowMsg]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::ShowMsg
[GroupManage]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::GroupManage
[IRCShell]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::IRCShell
[Openqq]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Openqq
[Perlcode]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Perlcode
[Perldoc]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Perldoc
[StockInfo]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::StockInfo
[ProgramCode]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::ProgramCode
[Translation]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Translation
[MobileInfo]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::MobileInfo
[Riddle]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Riddle
[GasPrice]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::GasPrice
[KnowledgeBase]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::KnowledgeBase
[FuckDaShen]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::FuckDaShen
[Qiandao]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Qiandao
[Pu]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Pu
[ZiYue]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::ZiYue
[PostImgVerifycode]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::PostImgVerifycode
[PostQRcode]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::PostQRcode
[UploadQRcode]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::UploadQRcode
[ShowQRcode]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::ShowQRcode
[SmartReply]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::SmartReply
[IPWhere]: https://git.oschina.net/ijz/Mojo-Webqq-IPwhere
[LCMD]: https://git.oschina.net/ijz/Mojo-Webqq-LCMD
[PW]: http://git.oschina.net/ijz/pullword/blob/master/example/PW.pm
[PostQRcodeToTelegram]: https://github.com/sjdy521/Mojo-Webqq/blob/master/lib/Mojo/Webqq.pod#Mojo::Webqq::Plugin::PostQRcodeToTelegram

==> Mojo-Webqq-2.0.3.tar.gz: Mojo-Webqq-2.0.3/Plugin.md <==
###插件列表

|名称                | 优先级  |当前状态    |github作者    | 功能说明                 
|:-------------------|:--------|:-----------|:-------------|:----------------------------
|[ShowMsg]           |100      |已发布      |sjdy521       |打印客户端接收和发送的消息
|[GroupManage]       |100      |已发布      |sjdy521       |群管理，入群欢迎、限制发图频率等
|[IRCShell]          |99       |已发布      |sjdy521       |Linux环境下通过irc客户端使用qq
|[Openqq]            |98       |已发布      |sjdy521       |提供qq发送消息api接口
|[GCM]               |97       |已发布      |sjdy521       |接收消息通过GCM推送到android手机
|[Perlcode]          |97       |已发布      |sjdy521       |通过qq消息执行perl代码
|[Perldoc]           |96       |已发布      |sjdy521       |通过qq消息查询perl文档
|[StockInfo]         |95       |已发布      |shalk         |查询股票信息
|[ProgramCode]       |94       |已发布      |limengyu1990  |通过qq消息执行代码，支持26种语言
|[Translation]       |93       |已发布      |sjdy521       |多国语言翻译功能
|[MobileInfo]        |93       |已发布      |limengyu1990  |手机号码归属地查询
|[Riddle]            |92       |已发布      |limengyu1990  |输入"猜谜"关键字进行猜谜游戏
|[GasPrice]          |91       |已发布      |hyvinlam      |输入"油价"关键字查询油价
|[KnowledgeBase]     |3        |已发布      |sjdy521       |自定义可编辑问答知识库
|[FuckDaShen]        |1        |已发布      |sjdy521       |对消息中的"大神"关键词进行鄙视
|[Qiandao]           |1        |已发布      |sjdy521       |QQ群每日签到
|[Pu]                |1        |已发布      |bollwarm      |周易、占卜、算命、八卦等关键字触发占卜
|[ZiYue]             |1        |已发布      |bollwarm      |子曰、论语、之乎者也等关键字触发论语语句
|[PostImgVerifycode] |0        |已发布      |sjdy521       |登录验证码发送到邮箱实现远程登录
|[PostQRcode]        |0        |已发布      |sjdy521       |登录二维码发送到邮箱实现远程扫码
|[UploadQRcode]      |0        |已发布      |sjdy521       |二维码上传图床获得公网访问url
|[ShowQRcode]        |0        |已发布      |autodataming  |调用系统图片查看程序来示二维码（目前仅支持win）
|[SmartReply]        |0        |已发布      |sjdy521       |智能聊天回复
|[IPWhere]           |1        |已发布      |bollwarm      |IP库查询
|[LCMD]              |1        |已发布      |bollwarm      |linux命令使用方法查询
|[PW]                |1        |已发布      |bollwarm      |在线分词pullword插件,pullword,分词 关键词触发
|[PostQRcodeToTelegram]|0      |已发布      |HubertZhang   |二维码通过Telegram Bot发至指定账户或频道或群组

[ShowMsg]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::ShowMsg
[GroupManage]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::GroupManage
[IRCShell]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::IRCShell
[Openqq]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Openqq
[Perlcode]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Perlcode
[Perldoc]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Perldoc
[StockInfo]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::StockInfo
[ProgramCode]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::ProgramCode
[Translation]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Translation
[MobileInfo]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::MobileInfo
[Riddle]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Riddle
[GasPrice]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::GasPrice
[KnowledgeBase]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::KnowledgeBase
[FuckDaShen]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::FuckDaShen
[Qiandao]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Qiandao
[Pu]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::Pu
[ZiYue]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::ZiYue
[PostImgVerifycode]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::PostImgVerifycode
[PostQRcode]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::PostQRcode
[UploadQRcode]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::UploadQRcode
[ShowQRcode]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::ShowQRcode
[SmartReply]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::SmartReply
[IPWhere]: https://git.oschina.net/ijz/Mojo-Webqq-IPwhere
[LCMD]: https://git.oschina.net/ijz/Mojo-Webqq-LCMD
[PW]: http://git.oschina.net/ijz/pullword/blob/master/example/PW.pm
[PostQRcodeToTelegram]: https://github.com/sjdy521/Mojo-Webqq/blob/master/lib/Mojo/Webqq.pod#Mojo::Webqq::Plugin::PostQRcodeToTelegram
[GCM]: https://metacpan.org/pod/distribution/Mojo-Webqq/doc/Webqq.pod#Mojo::Webqq::Plugin::GCM
